@@ -132,14 +132,17 @@ class ImageCharts:
 
   
   def chof(self, value: str):
-    """Some clients like Flowdock/Facebook messenger and so on, needs an URL to ends with a valid image extension file to display the image, use this parameter at the end your URL to support them. Valid values are &#34;.png&#34; and &#34;.gif&#34;
+    """Some clients like Flowdock/Facebook messenger and so on, needs an URL to ends with a valid image extension file to display the image, use this parameter at the end your URL to support them. Valid values are &#34;.png&#34;, &#34;.svg&#34; and &#34;.gif&#34;.
+	*           Only QRCodes and GraphViz support svg output.
 
     [Reference documentation]{@link https://documentation.image-charts.com/reference/output-format/}
     * @example
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
   * const chart = ImageCharts().{param.name}('{doc(example)}')
     @default '{param.default}'
 
-    - value :str - Output fake format
+    - value :str - Image output format
     """
     return self.__clone('chof', value)
 
@@ -189,6 +192,8 @@ class ImageCharts:
     [Reference documentation]{@link https://documentation.image-charts.com/reference/grid-lines/}
     * @example
   * const chart = ImageCharts().{param.name}('{doc(example)}')
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
   * const chart = ImageCharts().{param.name}('{doc(example)}')
     
 
@@ -336,6 +341,20 @@ class ImageCharts:
     return self.__clone('chl', value)
 
   
+  def chlps(self, value: str):
+    """Position and style of labels on data
+
+    [Reference documentation]{@link https://documentation.image-charts.com/reference/chart-label/#positionning-and-formatting}
+    * @example
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+    
+
+    - value :str - Position and style of labels on data
+    """
+    return self.__clone('chlps', value)
+
+  
   def chma(self, value: str):
     """chart margins
 
@@ -376,6 +395,20 @@ class ImageCharts:
     return self.__clone('chf', value)
 
   
+  def chbr(self, value: str):
+    """Bar corner radius. Display bars with rounded corner.
+
+    [Reference documentation]{@link https://documentation.image-charts.com/bar-charts/#rounded-bar}
+    * @example
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+  * const chart = ImageCharts().{param.name}('{doc(example)}')
+    
+
+    - value :str - Bar corner radius. Display bars with rounded corner.
+    """
+    return self.__clone('chbr', value)
+
+  
   def chan(self, value: str):
     """gif configuration
 
